######################################################################################################
#################################### PAPER DEMOGRAPHIC RESEARCH ######################################
######################################################################################################


# Cleaning everything before starting any analysis
rm(list=ls()) 

# Working directory
setwd("D:\\Mydocuments\\PhD research\\Methods_submission")

# *****************************************************************************************************
# *************************** Installing the required packages to be used *****************************
#install.packages("latticeExtra")
#library(reshape2)
#library(gtable)
library(tidyverse)
library(ggplot2)
library(forcats)
library(readxl)
library(plyr)
library(gridExtra)
library(grid)
library(foreign)
library(data.table)
library(nlme)
library(mgcv)
library(LifeTables)
library(HIV.LifeTables)
library(DDM)
library(lubridate) # to convert date into integer
library(psych)     # geometric mean
library(nlme)
library(scales)
library(ggthemes)
library(ggpubr) # extra themes for ggplot2
#library(MortalityEstimate)
library(svdComp5q0)
library(MortalityLaws)
# *****************************************************************************************************
# ******************************* chargement et prparation des donnes *******************************

# Importing the from an excel file
data <- as.data.frame(read_excel("rgphbf.xlsx", sheet = 1, skip = 0))
head(data);tail(data) 
str(data)

# Grouping rural and urban together 
dataf <- rbind(ddply(data, ~ annee + sexe + age, # <=> ou crire ".(annee,sexe,age)" : variables d'aggrgation
                  summarise, pop = sum(pop), deces = sum(deces)) %>%
            mutate(milres = "tot") %>%
            select(annee, milres, sexe, age, pop, deces), data) %>%
            mutate(milres=recode(milres, "rur"="r","urb"="u","tot"="tot"), 
                   milres=factor(milres, levels=c("r","u","tot")),
                   sexe=recode(sexe,"hom"="m","fem"="f"),
                   sexe=factor(sexe, levels=c("m","f")))

df <- subset(dataf, milres=="tot") %>% 
      select(annee, sexe, age, pop, deces) %>%
      arrange(annee, sexe, age)

#******************************************************************************************************
# ******************************* Creating pyramids for visualisation *********************************

# Computing the age-specific distribution (in proportion) 
dfpyr <- subset(df, age!=99)

for(ny in unique(dfpyr$annee)){
      i       <- dfpyr$annee == ny 
      chk     <- dfpyr[i, ]
      
      chk     <- mutate(chk, 
                        pp  = pop/sum(pop))
      
      dfpyr$pp[i]  <- chk$pp 
}

## Population pyramid using ggplot 
pyrpop <- ggplot(data = dfpyr, 
                 mapping = aes(x = age, y = pp*100, fill = sexe)) +
          # Bars for females
          geom_bar(data = filter(dfpyr, sexe=="f"),  
                   stat = "identity", width=0.8) +
          # Bars for males
          geom_bar(data = filter(dfpyr, sexe=="m"),
                   stat = "identity", position = "identity", width=0.8,
                   # Putting negative values for males bars from the pyramid center
                   mapping = aes(y = -pp*100)) +
          # facet_grid for each year
          facet_grid(cols=vars(as.factor(annee)), scales = "free_y") + 
          # Defining the axis graduation
          scale_x_continuous(breaks = c(seq(0,90,10),98), expand=c(0,2), name = "Age\n") +
          scale_y_continuous(breaks = seq(-2.2, 2.2,1.1), limits =c(-2.2,2.2),
                             labels = abs, # taking out the negative values for males
                             name = "\nPopulation (%)") +
          # Dfining the color and labels for bars
          scale_fill_manual(values=c("f"="salmon","m"="skyblue"), 
                            labels=c("f"="Females","m"="Males")) +
          # Flipping the bars verticaly rather than horizontaly(by default)
          coord_flip() + theme_bw() + #scale_fill_stata() +
          theme(legend.title = element_blank(), legend.position = "bottom", legend.box = "horizontal", 
                legend.spacing.x = unit(0.2, "cm"), legend.background=element_rect(color=NA),
                legend.text=element_text(size=14), axis.title=element_text(size=14), 
                axis.text.x=element_text(size=14), axis.text.y=element_text(angle=0, size=14),
                strip.placement="outside", strip.text=element_text(size=14),
                panel.grid.minor = element_blank()) 
                

## Deaths pyramid
pyrdec <- ggplot(data = dfpyr, 
                 mapping = aes(x = age, y = log(deces), fill = sexe)) +
          geom_bar(data = filter(dfpyr, sexe=="f"), 
                   stat = "identity", width=0.8) +
          geom_bar(data = filter(dfpyr, sexe=="m"),
                   stat = "identity", position = "identity", width=0.8, 
                   mapping = aes(y = -log(deces))) +
          facet_grid(cols=vars(as.factor(annee)), scales = "free_y") +
          scale_x_continuous(breaks = c(seq(0,90,10),98), expand=c(0,2), name = "Age\n") +
          scale_y_continuous(breaks = seq(-10,10,5), limits =c(-10,10),
                             labels = abs, name = "\nDeaths (log-scale))") +
          scale_fill_manual(values=c("f"="salmon","m"="skyblue"), 
                            labels=c("f"="Females","m"="Males")) +
          coord_flip() + theme_bw() +
          theme(legend.position = "none", axis.title=element_text(size=14), 
                axis.text.x=element_text(size=14), axis.text.y=element_text(angle=0,size=14), 
                strip.placement="outside", strip.text=element_text(size=14),
                panel.grid.minor = element_blank()) 


# Saving the pyramid plots
grid.newpage()
ggsave(filename="pyrplot.png",
       plot = grid.draw(rbind(ggplotGrob(pyrpop), ggplotGrob(pyrdec), size="last")),
       width=8, height=8)
dev.off()

#**************************************************************************************************
# *************************************** DATA PROCESSING ***************************************** 

# Grouping the data by 5-year classic age groups until age 85
dfa1  <- df %>% 
          mutate(agecat=cut(age, breaks=c(seq(0,90,5),99,100), 
                            labels=c("0-4","5-9","10-14","15-19","20-24","25-29","30-34","35-39",
                                     "40-44","45-49","50-54","55-59","60-64","65-69","70-74",
                                     "75-79","80-84","85-89","90+","99"),include.lowest=T, right=F)) %>% 
          # aggregating the data by summing in each eacg age group using ddply
          ddply(.(annee, sexe, agecat), summarise, pop = sum(pop), deces = sum(deces)) %>%
          # Creating an age variable that corresponds to the ower bound of each age group
          mutate(age=recode(agecat,"0-4"=0,"5-9"=5,"10-14"=10,"15-19"=15,"20-24"=20,"25-29"=25,"30-34"=30,
                            "35-39"=35,"40-44"=40,"45-49"=45,"50-54"=50,"55-59"=55,"60-64"=60,"65-69"=65,
                            "70-74"=70,"75-79"=75,"80-84"=80,"85-89"=85,"90+"=90,"99"=99), grp="c") %>% 
          # Arranging the data in a certain order
          select(annee, sexe, agecat, age, pop, deces, grp)

# Grouping the data by 5-year non-classic age groups until age 88
dfa2  <- df %>% 
           mutate(agecat=cut(age, breaks=c(0,seq(8,88,5),99,100), 
                              labels=c("0-7","8-12","13-17","18-22","23-27","28-32","33-37","38-42",
                                      "43-47","48-52","53-57","58-62","63-67","68-72","73-77",
                                       "78-82","83-87","88+","99"),include.lowest=T, right=F)) %>% 
           # aggregating the data by summing in each eacg age group using ddply
           ddply(.(annee, sexe, agecat), summarise, pop = sum(pop), deces = sum(deces)) %>%
           # Creating an age variable that corresponds to the ower bound of each age group
           mutate(age=recode(agecat, "0-7"=0,"8-12"=10,"13-17"=15,"18-22"=20,"23-27"=25,"28-32"=30,"33-37"=35,
                             "38-42"=40,"43-47"=45,"48-52"=50,"53-57"=55,"58-62"=60,"63-67"=65,"68-72"=70,
                             "73-77"=75,"78-82"=80,"83-87"=85,"88+"=90,"99"=99), # using classic age bound to easy compute the completeness
                  grp="nc") %>% 
           # Arranging the data in a certain order
           select(annee, sexe, agecat, age, pop, deces, grp)



# rbinding data from different age groups
dfa <- rbind(dfa1, dfa2)

# Redistributing unknown ages 
for(ag in unique(dfa$grp)){
  for(ny in unique(dfa$annee)){ 
    for(ns in unique(dfa$sexe)){ 
    i    <- dfa$grp == ag & dfa$annee == ny & dfa$sexe == ns 
    chk  <- dfa[i, ]
    x    <- chk$age
    e    <- chk$pop
    d    <- chk$deces
    
    dfa$px[i]  <- ifelse(x==99, NA, round(e[x!=99] * (sum(e)/sum(e[x!=99]))))
    dfa$dx[i]  <- ifelse(x==99, NA, round(d[x!=99] * (sum(d)/sum(d[x!=99]))))
    
  }
 }
}

# Dropping the rows of unknown ages and filtering age > 15 
dfa <- subset(dfa, age!=99, select=-c(pop,deces)) %>% 
        rename(c("px"="pop","dx"="deces")) %>%
        filter(age>=15)
head(dfa); tail(dfa)

# Internal checks of age ratios
dfar <- dfa
for(ag in unique(dfar$grp)){
  for(ny in unique(dfar$annee)){ 
    for(ns in unique(dfar$sexe)){ 
      i    <- dfar$grp == ag & dfar$annee == ny & dfar$sexe == ns 
      chk  <- dfar[i, ]
      x    <- chk$age
      g    <- chk$grp
      e    <- chk$pop
      d    <- chk$deces
      
      dfar$arpx[i]  <- ifelse(x==90 , NA, 3 * e/(lag(e) + e + lead(e) )) 
      dfar$ardx[i]  <- ifelse(x==90 , NA, 3 * d/(lag(d) + d + lead(d) ))
    } 
  }
}

# Dropping NAs in the age-ratios file and computing Deaths over Population age ratios
dfar  <- rbind(subset(dfar, !is.na(arpx)) %>% 
               select(annee, sexe, agecat, grp, arpx) %>%
               rename(c("arpx"="ar")) %>% 
               mutate(type="Population"),
               subset(dfar, !is.na(ardx)) %>% 
               select(annee, sexe, agecat, grp, ardx) %>%
               rename(c("ardx"="ar")) %>% 
               mutate(type="Deaths")) %>%
               # computing ratios of age-ratios
               as.data.table() %>%
               dcast.data.table(annee + sexe + agecat + grp ~ type, value.var=c("ar")) %>%
               mutate(rar = Deaths/Population) #%>%

head(dfar); tail(dfar)

# Comparing age-ratios in deaths and population
rarplot <- ggplot(dfar) + 
           geom_line(aes(x=agecat, y=rar, group=sexe, color=sexe), lwd=1) + 
            geom_hline(aes(yintercept = 1), color="black", alpha=0.5, size=0.5) +
            geom_rect(aes(xmin=ifelse(grp=="c","70-74","68-72"), ymin=-Inf, xmax=Inf, ymax=Inf), show.legend=F, 
                      color=NA, fill="red", alpha=0.005) +
            scale_color_manual(values=c("f"="salmon","m"="skyblue"), 
                               labels=c("f"="Females ", "m"="Males")) +
            facet_grid(rows=vars(as.factor(annee)), cols=vars(grp), scales = "free", 
                       labeller = labeller(grp=c("c"="classic age groups", "nc"="non-classic age groups"))) + 
            labs(x="\nAge groups", y="Ratio of age-ratios (Deaths over Population)\n") +
            scale_y_continuous(breaks = c(0.5,1,1.5), limits=c(0.5,1.5))  + 
            theme_bw() + theme(legend.title = element_blank(), legend.background=element_rect(color=NA),
                               legend.position = "bottom", legend.spacing.x = unit(0.2, "cm"),
                               legend.text=element_text(size=14), axis.title = element_text(size=12), 
                               axis.text.x=element_text(angle=90, size=12, hjust=1, vjust=0.5),
                               axis.text.y = element_text(angle=0,size=12),
                               panel.spacing.y=unit(1, "lines"), panel.grid.minor.x = element_blank(),
                               panel.grid.major.x = element_blank(), panel.grid.minor.y = element_blank(),
                               strip.placement="outside", strip.text=element_text(size=12)) 

# Saving the age-ratios plots
grid.newpage()
ggsave(filename="rarplot.png",
       plot = rarplot,
       width=8, height=6)
dev.off()

# ******************************************************************************************************
# ************************************** INTERCENSAL ADJUSTEMENTS **************************************
# Working with non-classical data 
dfag <- subset(dfa, grp =="nc") %>% select(-grp)  


# Information on starting and end dates of the censuses
s85 <- as.Date("1984-12-14", format="%Y-%m-%d")
e85 <- as.Date("1985-12-15", format="%Y-%m-%d")
s96 <- as.Date("1995-12-14", format="%Y-%m-%d")
e96 <- as.Date("1996-12-15", format="%Y-%m-%d")
s06 <- as.Date("2005-12-15", format="%Y-%m-%d")
e06 <- as.Date("2006-12-16", format="%Y-%m-%d")

# Preparing data files for each intercensal period
dat1 <-  subset(dfag, annee!=2006) %>% 
         mutate(cod = ifelse(sexe=="f", 1, 2), 
                year1=decimal_date(e85), year2=decimal_date(e96)) %>%
         select(cod, annee, sexe, agecat, age, pop, deces, year1, year2)

dat2 <-  subset(dfag, annee!=1985) %>% 
         mutate(cod = ifelse(sexe=="f", 3, 4), 
                year1=decimal_date(e96), year2=decimal_date(e06)) %>%
         select(cod, annee, sexe, agecat, age, pop, deces, year1, year2) 

# Putting the data together to have one census followed by the next
dat   <- dcast.data.table(as.data.table(dat1),
                          cod + sexe + agecat + age + year1 + year2 ~ annee, 
                          value.var=c("pop","deces")) %>%
         rename(c("pop_1985"="pop1","pop_1996"="pop2","deces_1985"="d1",
                  "deces_1996"="d2", "sexe"="sex")) %>%
         rbind(dcast.data.table(as.data.table(dat2), 
                                cod + sexe + agecat + age + year1 + year2 ~ annee, 
                                value.var=c("pop","deces")) %>%
         rename(c("pop_1996"="pop1", "pop_2006"="pop2", "deces_1996"="d1", 
                  "deces_2006"="d2", "sexe"="sex"))) %>%
         mutate(sex = as.character(sex))
head(dat)

# Fonction to compute intercensal deaths following the Tools excel template 
interdx <- function(d1, s1, e1, d2, s2, e2){
  
  ## calculing mid-intercensal period
  m1 <- s1 + floor((e1-s1)/2)
  m2 <- s2 + floor((e2-s2)/2)
  
  ## Bounds over which intercensal deaths should be calculated
  stda <- e1+1
  enda <- e2
  yr   <- 365.25
  
  ## Year fractions
  yf1 <- as.numeric((e1-s1))/yr
  yf2 <- as.numeric((e2-s2))/yr
  yfm <- as.numeric((m2-m1))/yr
  yf3 <- as.numeric(enda+1-m1)/yr
  yf4 <- as.numeric(stda-m1)/yr
  yf5 <- as.numeric(e1+1-s1)/yr
  
  ## growth rates
  r <- log( (d2/yf1) / (d1/yf2) ) / yfm
  
  ## Estimated number of intercensal deaths 
  d12 <- d1*(exp(r*yf3) - exp(r*yf4)) / (r*yf5)
  
  return(round(d12)) 
}

## Testing the function
interdx(d1=subset(dat, cod==1)$d1, d2=subset(dat, cod==1)$d2, s1=s85, s2=s96, e1=e85, e2=e96)

## Computing intercensal deaths and arranging the classic age groups file  
dat <- dat %>% 
       mutate(deaths=ifelse(cod==1, interdx(d1=subset(dat, cod==1)$d1, d2=subset(dat, cod==1)$d2,
                                            s1=s85, s2=s96, e1=e85, e2=e96),
                            ifelse(cod==2, interdx(d1=subset(dat, cod==2)$d1, d2=subset(dat, cod==2)$d2, 
                                                   s1=s85, s2=s96, e1=e85, e2=e96),
                                   ifelse(cod==3, interdx(d1=subset(dat, cod==3)$d1, d2=subset(dat, cod==3)$d2, 
                                                          s1=s96, s2=s06, e1=e96, e2=e06),
                                          interdx(d1=subset(dat, cod==4)$d1, d2=subset(dat, cod==4)$d2, 
                                                  s1=s96, s2=s06, e1=e96, e2=e06))))) %>% 
       select(cod, pop1, pop2, deaths, year1, year2, age, sex, agecat) 
       
head(dat)


# Adjusting for the completeness of deaths
df0    <- NULL

for(co in unique(dat$cod)){
  
            i      <- dat$cod == co
            covx   <- dat[i,]
            # minimum age to adjust for the completeness
            adma   <- 40
            
            covx   <- mutate(covx, 
                            mina  = ggb(covx, minA=adma, deaths.summed = T)[1,3]-2,
                            maxa  = ggb(covx, minA=adma, deaths.summed = T)[1,4]+2,
                            delta = ggb(covx, minA=adma, deaths.summed = T)[1,5],
                            Cx    = ggbsegMakeColumns(covx, agesFit = seq(adma,75,5), deaths.summed = T)$Cx,
                            Cxq1  = quantile(Cx[age %in% seq(adma,75,5)], 0.25),
                            mcov  = ggbseg(covx, minA=adma, deaths.summed = T)[1,2],
                            Cxq3  = quantile(Cx[age %in% seq(adma,75,5)], 0.75),
                            ti    = year2-year1,
                            pop1adj = ifelse(delta<0, pop1*exp(-delta*ti), pop1),
                            pop2adj = ifelse(delta>0, pop2*exp(-delta*ti), pop2),
                            D       = deaths/mcov,
                            E       = ti*sqrt(pop1adj*pop2adj)) %>%
                            
              select(cod, pop1adj, pop2adj, deaths, year1, year2, age, sex, agecat, mina, maxa, 
                     delta, Cx, Cxq1, mcov, Cxq3, ti, D, E) %>%
              rename(c("pop1adj"="pop1", "pop2adj"="pop2"))
            
            df0   <- rbind(df0, covx)
           
}


# Creating the period variable into the data.frame
df0 <- mutate(df0, period=ifelse(cod==1|cod==2, "1985-1996","1996-2006"))

# Diagnostic plot when correcting the data for incompleteness of deaths
ggbsegplot <- ggplot(filter(df0, age %in% seq(40,75,5))) + 
              geom_point(aes(x=age+0.5, y=Cx), color=gray(0.5), shape=18, size=3) +
              geom_hline(aes(yintercept=mcov), color="red3", size=0.5) +
              geom_rect(aes(xmin=min(age)-2, xmax=max(age)+2, ymin=Cxq1, ymax=Cxq3), 
                        fill="orange", alpha=0.04) +
              geom_text(aes(label=paste("census diff. coverage delta  =", round(delta,3)), y=mcov-0.2), 
                        x=57,  size=4, color="cadetblue4") + 
              geom_text(aes(label=paste("Death completeness =", round(mcov,3)), y=mcov-0.4), 
                        x=57, size=4, color="red3") + 
              facet_grid(rows=vars(period), cols=vars(sex), 
              labeller = labeller(sex=c("f"="Females", "m"="Males"))) +
              scale_x_continuous(breaks = seq(38,78,5), limits = c(38,78)) +
              scale_y_continuous(breaks = seq(0,1,0.2), limits=c(0,1)) + labs(x="Age") +
              theme_bw() + theme(panel.grid = element_blank(), 
                                 axis.title = element_text(size=14),
                                 axis.text = element_text(size=14), 
                                 strip.text = element_text(size=14))

# Saving the ddm diagnistic plot
grid.newpage()
ggsave(filename="ggbsegplot.png",
       plot = ggbsegplot,
       width=8, height=7)
dev.off()

# Computing life table from classical and non-classical age groups
for(co in unique(df0$cod)){
  
      i      <- df0$cod == co
      codi   <- df0[i,]
      w      <- max(codi$age)
      radix  <- 1
      
      codi   <- mutate(codi,                           
                       # Life tables functions
                       n  = diff(age)[1],
                       mx.nc = D/E,
                       qx.nc = ifelse(age < w, 2*n*mx.nc/(2 + n*mx.nc), 1),#1-exp(-n*mx)),
                       ax.nc = ifelse(age < w, n/2, 1/mx.nc),
                       lx.nc = c(radix, cumprod(1 - qx.nc)[-length(qx.nc)]),
                       dx.nc = qx.nc * lx.nc,
                       Lx.nc = dx.nc/mx.nc,
                       Tx.nc = rev(cumsum(rev(Lx.nc))),
                       ex.nc = Tx.nc/lx.nc,
                            
                       # Interpolating survival function to match classical age groups using n=2
                       lxs = (lx.nc - 2*2*mx.nc/(2 + 2*mx.nc) * lx.nc), 
                       lx  = lxs/lxs[1], # rescaling the lx to start a radix of 1
                       dx  = ifelse(age < w, rev(diff(rev(lx))), lx),
                       # Computing the other functions from the lx
                       Lx  = n*(lx - dx) + ax.nc*dx, # (ax.nc-2)*lx
                       mx  = dx / Lx,
                       qx  = dx/lx,
                       ax  = ifelse(age < w, n/2, 1/mx),
                       Tx  = rev(cumsum(rev(Lx))),
                       ex  = Tx/lx)
            
            # Adding columns of interest in the master file
            df0$mx.nc[i]    <- codi$mx.nc
            df0$qx.nc[i]    <- codi$qx.nc
            df0$ax.nc[i]    <- codi$ax.nc
            df0$lx.nc[i]    <- codi$lx.nc
            df0$dx.nc[i]    <- codi$dx.nc
            df0$Lx.nc[i]    <- codi$Lx.nc
            df0$Tx.nc[i]    <- codi$Tx.nc
            df0$ex.nc[i]    <- codi$ex.nc
            
            df0$mx[i]       <- codi$mx
            df0$qx[i]       <- codi$qx
            df0$ax[i]       <- codi$ax
            df0$lx[i]       <- codi$lx
            df0$dx[i]       <- codi$dx
            df0$Lx[i]       <- codi$Lx
            df0$Tx[i]       <- codi$Tx
            df0$ex[i]       <- codi$ex
            
}

# Having a look at the plot
ggplot(df0) + 
  geom_line(aes(x=age+0.5, y=mx.nc), color=gray(0.5), size=1) +
  geom_line(aes(x=age+2.5, y=mx), color="red", size=1) +
  #geom_line(aes(x=age+2.5, y=mx.vr), color="gold", size=1) +
  facet_grid(rows=vars(period), cols=vars(sex)) +
  # scale_x_continuous(breaks = seq(38,78,5), limits = c(38,78)) +
  scale_y_continuous(trans = "log") + labs(x="Age") +
  theme_bw() + theme(panel.grid = element_blank(), 
                     axis.title = element_text(size=14),
                     axis.text = element_text(size=14), 
                     strip.text = element_text(size=14))

# Defining the adjusted as the basic estimates
df0 <- df0 %>% mutate(method="Adjusted for incompleteness")
head(df0); tail(df0)
# ******************************* PREPARING THE DATA FOR MODELISATION *******************************

# Deriving indice of adult mortality 45q15
qadult <- ddply(df0, .(cod), summarize, qadu= 1 - lx[age==60]/lx[age==15])

# Importing child mortality from UN-IGME
q05all <- read.table("q05igme_bfa.txt", header = T, sep = "\t") 

# Using GAM for backward interpolation of sex-specific 5q0 given the yearly total 5q0(q05t) 
# from 1985.5 to 1989.5
q05all["q05fs"] <- plogis(predict(gam(logit(q05f) ~ te(year) + te(q05t), 
                                      data=subset(q05all, year %in% c(1990.5:2006.5))),  q05all))

q05all["q05ms"] <- plogis(predict(gam(logit(q05m) ~ te(year) + te(q05t), 
                                      data=subset(q05all, year %in% c(1990.5:2006.5))),  q05all))

# Mean information on child mortality (5q0) over each intercensal period  
qchild <- q05all %>% select(year, q05f) %>% rename(c("q05f"="q05")) %>% mutate(sex="f") %>%
          rbind(q05all %>% select(year, q05m) %>% rename(c("q05m"="q05")) %>% mutate(sex="m")) %>%
          mutate(cod=ifelse(year <= 1996.5 & sex=="f", 1, 
                            ifelse(year <= 1996.5 & sex=="m", 2,
                                   ifelse(year > 1996.5 & sex=="f", 3, 4)))) %>%
          ddply(.(cod), summarize, q05=geometric.mean(q05))


# Importing mean information on HIV prevalence over each intercensal period from UNAIDS  
#hiv    <- read.table("hivprev_bfa.txt", header = T, sep = "\t")

# Synthesis input parameters for relational models
par.input  <-  data.frame(qchild, qadu=qadult[,2]) #, hiv=hiv[,2]
par.input

#**************************************************************************************************
#*************************  IMPLEMENTING THE BRASS & THE SVDComp MODEL  ***************************

 
# Loading Indepth african standard
idpstd   <- read.table("indepth_std.txt", header = T, sep = "\t")


dfbras    <- NULL
dfsvd     <- NULL

for(i in 1:length(unique(df0$cod))){
  
  brass    <- df0[df0$cod==i,] 
  
  radix    <- 1
  
  inf.adj  <- 35
  sup.adj  <- 65
  
  inf.svd  <- 35
  sup.svd  <- 65
  
  age      <- c(0, 1, seq(5, 110,5))
  
  brass1   <- mutate(brass,
                     # importing standard survival for logit calculations
                     lxs   = ifelse(sex == "m", idpstd$lxs1m[idpstd$age %in% age],
                                    idpstd$lxs1f[idpstd$age %in% age]),
                     # puting the radix of the standard to 1
                     lxsrad1 = lxs/lxs[1],
                     # Brass logit of the standard
                     yxs   = 0.5*qlogis(1-lxsrad1),
                     
                     # Computing the Brass logit of the adjerved survival
                     yx.adj = 0.5*qlogis(1-lx), 
                     # Relating the logit of the adjerved survival directly to the indepth standard
                     
                     bet  = sd(yx.adj[age %in% seq(inf.adj,sup.adj,5)]) / sd(yxs[age %in% seq(inf.adj,sup.adj,5)]),
                     alp  = mean(yx.adj[age %in% seq(inf.adj,sup.adj,5)]) - bet*mean(yxs[age %in% seq(inf.adj,sup.adj,5)]),
                     
                     yxfit= alp[1] + bet[1] * yxs,
                     # Direct fitted survival curve from the adjerved and Indepth african standard
                     lxfit = c(1, 1/(1 + exp(2*yxfit[-1]))),
                     qxfitted = 1-c(lxfit[-1],0)/lxfit) #qxfit= dxfit / lxfit,
  
  brass2   <- mutate(brass1[-nrow(brass1),],
                     qxfit= ifelse(age < max(age), qxfitted, 1),
                     n    = diff(age)[1],
                     mxfit= - log(1-qxfitted)/n,
                     dxfit= qxfit * lxfit,
                     Lxfit= dxfit / mxfit,
                     axfit= ifelse(age < max(age), n/2, 1/mxfit),
                     Txfit= rev(cumsum(rev(Lxfit))),
                     exfit= Txfit/lxfit)
  
   #brass3    <- select(brass2, cod, sex, period, alp, bet) 
  
   svd.input <- subset(par.input, cod==i)
   qxpred    <- predictLT(sex = ifelse(svd.input$cod %in% c(1,3), "female", "male"),
                          cm  = svd.input$q05, 
                          am  = svd.input$qadu,
                          out5 = T)[,1]
   
   svdchk  <- data.frame(cod    = svd.input$cod,
                         age    = c(0,1, seq(5,110,5)),
                         qxpred = qxpred) %>%
              mutate(lxpred = c(radix, cumprod(1 - qxpred)[-length(qxpred)])) %>%
              filter(age >=15) 
  
   svdchk2 <- subset(svdchk, age<=85) %>%
              mutate(n = diff(age)[1],
                     lx.svd = lxpred/lxpred[1],
                     qx.svd = ifelse(age < max(age), qxpred, 1),
                     dx.svd = qx.svd*lx.svd,
                     mx.svd = 2*qxpred/(2*n-n*qxpred),
                     ax.svd = ifelse(age < max(age), n/2, 1/mx.svd),
                     Lx.svd = dx.svd/mx.svd,
                     Tx.svd = rev(cumsum(rev(Lx.svd))),
                     ex.svd = Tx.svd/lx.svd) %>%
              mutate(sex=ifelse(cod==1|cod==3, "f", "m"),
                     period=ifelse(cod==1|cod==2, "1985-1996", "1996-2006"))
    
   dfbras  <- rbind(dfbras, brass2)
   dfsvd   <- rbind(dfsvd, svdchk2)
}

dfsvd  <-  dfsvd %>% 
           mutate(method="SVD model") 
dfbras <-  dfbras %>% 
           mutate(method="BRASS model") 


ggplot() +
  geom_line(data=df0, aes(x=age+0.5, y=mx.nc), color="black") + 
  geom_line(data=dfbras, aes(x=age+2.5, y=mxfit), color="blue") +
  geom_line(data=dfsvd, aes(x=age+2.5, y=mx.svd), color="red") +
  facet_grid(rows=vars(period), cols=vars(sex)) +
  scale_y_continuous(trans="log")
#***************************************************************************************************
#******************************** ADJUSTMENT USING MAKEHAM MODEL ***********************************

# Preparing the data to fit the MKH model

# agemkh <- seq(35,85)
# dfmkh  <- expand.grid(cod=unique(df0$cod), age2=agemkh) %>% 
#           left_join(subset(mutate(df0, age2=age-2), select=c(cod, age2, D, E)), 
#                     by.x=c("cod"="cod", "age2"="age2")) %>% 
#           arrange(cod, age2)

my_gomp_mkh <- function(x, par = c(b = 0.13, M = 45, k=0.01)){
  hx  <- with(as.list(par), b*exp(b*(x - M)) + k )
  return(as.list(environment()))
}


dfmkh  <- df0 %>% select(cod, age, sex, period, D, E) %>%
          mutate(x=age-2)
mkhpred <- NULL
# Fitting the model to the data
for(i in 1:length(unique(dfmkh$cod))){
  
  # chunk of intercensal data
  mkh  <- dfmkh[dfmkh$cod==i,]
  w    <- max(mkh$x)
  l    <- length(mkh$x)
  
  ageminfit <- 38
  agemaxfit <- 68
  fita  <- seq(ageminfit, agemaxfit, 5)
  #startval <- c(0.1, 80, 0.01)
  radix <- 1
  
  # Selecting the data.frame to be used to fit the parameters
  mkh2   <- mkh[mkh$cod==i & mkh$x %in% fita,]
  
  fitm   <- MortalityLaw(x=mkh2$x, Dx=mkh2$D, Ex=mkh2$E, custom.law=my_gomp_mkh)
  
  # plot(x=35:85+0.5, y=predict(fitm, x=seq(40,85,5)), log="y")
  # lines(x=na.omit(mkh)$age2+2.5, y=na.omit(mkh)$D/na.omit(mkh)$E)
  mkhfita <- seq(40,85,5)
  # Importing the estimate into the chunk
  mkh3   <- expand.grid(cod=unique(mkh$cod), sex=unique(mkh$sex), 
                      period=unique(mkh$period), age=mkhfita) %>%
            mutate(n  = diff(age)[1],
                   mx = predict(fitm, x = mkhfita),
                   # Estimated mx and related indicators
                   qx = ifelse(age < max(age), 2*n*mx/(2 + n*mx), 1),
                   ax = ifelse(age < max(age), n/2, 1/mx),
                   lx = c(radix, cumprod(1 - qx)[-length(qx)]),
                   dx = qx * lx,
                   Lx = dx/mx,
                   Tx = rev(cumsum(rev(Lx))),
                   ex = Tx/lx)
  mkhpred  <- rbind(mkhpred, mkh3)               

  # dfmkh$mx[dfmkh$cod==i ]    <- mkh3$mx
  # dfmkh$qx[dfmkh$cod==i ]    <- mkh3$qx
  # dfmkh$ax[dfmkh$cod==i ]    <- mkh3$ax
  # dfmkh$lx[dfmkh$cod==i ]    <- mkh3$lx
  # dfmkh$dx[dfmkh$cod==i ]    <- mkh3$dx
  # dfmkh$Lx[dfmkh$cod==i ]    <- mkh3$Lx
  # dfmkh$Tx[dfmkh$cod==i ]    <- mkh3$Tx
  # dfmkh$ex[dfmkh$cod==i ]    <- mkh3$ex
  
}

# The data.frame from the MKH model
mkhpred <- mkhpred %>% 
         mutate(method="MKH model") 
head(mkhpred); tail(mkhpred)

# Graphics of age-pattern by method
asdrplot <- ggplot() + 
              geom_line(data=df0, aes(x=age+0.5, y=mx.nc, color="Adjusted for incompleteness"), lwd=1.2, alpha=0.6) +
              geom_line(data=dfsvd, aes(x=age+2.5, y=mx.svd, color="SVD model"), lwd=1) +
              geom_line(data=dfbras, aes(x=age+2.5, y=mxfit, color="BRASS model"), lwd=1) +
              geom_line(data=mkhpred, aes(x=age+2.5, y=mx, color="MKH model"), lwd=1.2, alpha=0.6) +
              geom_vline(data=df0, aes(xintercept = 50), color="darkred", alpha=0.2) +
              geom_vline(data=df0, aes(xintercept = 70), color="red", alpha=0.2) +
              geom_vline(data=df0, aes(xintercept = 80), color="darkred", alpha=0.2) +
              annotate("rect", xmin=50, xmax=70, ymin=0, ymax=Inf, fill="red", alpha=0.02) +
              annotate("rect", xmin=70, xmax=80, ymin=0, ymax=Inf, fill="red", alpha=0.08) +
        
              scale_color_manual(values=c("Adjusted for incompleteness"="black","SVD model"="darkred",
                                          "BRASS model"="orange", "MKH model"="yellow3")) +
              
              facet_grid(period ~ sex, labeller=labeller(sex=c(f="Females", m="Males"))) + 
              labs(x="Age", y="Death rates (log-scale)\n") +
              scale_x_continuous(breaks = seq(20,80,10), limits = c(15,85)) + 
              scale_y_continuous(trans = "log", labels = scales::number_format(accuracy = 0.001)) +
              theme_bw() + #scale_color_stata() +
              theme(legend.background=element_rect(color=NA), legend.title=element_blank(), 
                    legend.position = "bottom", legend.box = "horizontal", 
                    legend.spacing.x = unit(0.01, "cm"), 
                    legend.text=element_text(size=18), axis.title=element_text(size=18), 
                    axis.text.x=element_text(size=18), axis.text.y=element_text(angle=0, size=18),
                    strip.placement="outside", strip.text=element_text(size=18))


# Saving the asdr plots
grid.newpage()
ggsave(filename="asdrplot.png",
       plot = asdrplot,
       width=10, height=9)
dev.off()

#************************************************************************************
# ANALYSIS OF KEY INDICATORS

# Row binding the data.frames from all the method implemented 
dft <- subset(df0, select=c(period, sex, method, age, lx)) %>% #mutate(age=age + 2) %>%
       rbind(subset(dfsvd, select=c(period, sex, method, age, lx.svd))  %>% rename(c("lx.svd"="lx"))) %>%
       rbind(subset(dfbras, select=c(period, sex, method, age, lxfit)) %>% rename(c("lxfit"="lx"))) %>%
       rbind(subset(mkhpred, select=c(period, sex, method, age, lx))) %>%
       mutate(method=factor(method, levels = c("Adjusted for incompleteness","SVD model",
                                                "BRASS model","MKH model"))) 
# Summary indicators
qab  <- ddply(dft, .(period, sex, method), summarize, 
              q5060 = 1- lx[age==60]/lx[age==50],
              q6070 = 1- lx[age==70]/lx[age==60],
              q7080 = 1- lx[age==80]/lx[age==70],
              q5070 = 1- lx[age==70]/lx[age==50],
              q5080 = 1- lx[age==80]/lx[age==50]) %>%  
         melt(id.vars = c("period","sex","method")) %>%
         rename(c("variable"="meas1", "value"="level")) %>%
         mutate(meas2=recode(meas1,
                             "q5060"="{}[{10}]*q[50]",
                             "q6070"="{}[{10}]*q[60]",
                             "q7080"="{}[{10}]*q[70]", 
                             "q5070"="{}[{20}]*q[50]",
                             "q5080"="{}[{30}]*q[50]"))

head(qab); tail(qab)


# Graphics of qmeas by method
qmeasplot <- ggplot() + 
              geom_line(data=subset(qab, meas2!="{}[{20}]*q[50]" & meas2!="{}[{30}]*q[50]"), 
                        aes(x=meas2, y=level, group=method, color=method), size=1, alpha=0.6) + 
              # geom_bar(data=subset(qab, meas2=="{}[{20}]*q[50]" | meas2=="{}[{30}]*q[50]"), 
              #          aes(x=meas2, y=level, fill=method), 
              #          stat="identity",position=position_dodge(0.9), alpha=0.6) + 
              facet_grid(period ~ sex, labeller=labeller(sex=c(f="Females",m="Males"))) + 
              scale_fill_manual(values=c("SVD model"="darkred","BRASS model"="orange", 
                                         "Adjusted for incompleteness"="black",
                                         "MKH model"="yellow3")) +
              scale_color_manual(values=c("SVD model"="darkred","BRASS model"="orange", 
                                          "Adjusted for incompleteness"="black",
                                          "MKH model"="yellow3")) +
              #scale_color_brewer(palette = "YlGnBu") +
              labs(x="Mortality indices", y="Risks of death\n") +
              scale_x_discrete(labels=parse(text=levels(qab$meas2))) + 
              scale_y_continuous(breaks = seq(0.1,0.7,0.2), limits=c(0.1,0.7)) + theme_bw() + 
              theme(legend.background=element_rect(color=NA), legend.title=element_blank(), 
                    legend.position = "bottom", legend.box = "horizontal", legend.spacing.x = unit(0.01, "cm"), 
                    legend.text=element_text(size=14), axis.title=element_text(size=14), 
                    axis.text.x=element_text(size=14), axis.text.y=element_text(angle=0, size=14),
                    strip.placement="outside", strip.text=element_text(size=14))

# Saving the qmeas plots
grid.newpage()
ggsave(filename="qmeasplot.png",
       plot = qmeasplot,
       width=9, height=7)
dev.off()

#################################################################################################
# COMPARING OUR ESTIMATES WITH UNPD ESTIMATES BY CHECKING DIFFERENCES IN 45q15 

# Computing 5q0 over the 5-year group to match the UN estimates
qc   <- subset(q05all, year!=c(2005.5,2006.5), select=c(year, q05fs, q05ms)) %>% 
        mutate(yrgrp=cut(year, breaks=c(seq(1985.5,2000.5,5),2005.5),
                         labels=c("1985-1989","1990-1994","1995-1999","2000-2004"),
                         include.lowest=T, right=F),
               q05fs=as.numeric(q05fs), 
               q05ms=as.numeric(q05ms)) %>%
        ddply(.(yrgrp), summarise, q05f=geometric.mean(q05fs), q05m=geometric.mean(q05ms))

qaf   <- c(0.288,0.301,0.302,0.297) ; qam   <- c(0.345,0.361,0.374,0.349)  

qac   <- cbind(qc, q1545f=qaf, q1545m=qam)


q8589f <- data.frame(period="1985-1989", sex="female",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="female", cm=qac[1,2], out5 = TRUE, am = qac[1,4])[,1])
q9094f <- data.frame(period="1990-1994", sex="female",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="female", cm=qac[2,2], out5 = TRUE, am = qac[2,4])[,1])
q9599f <- data.frame(period="1995-1999", sex="female",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="female", cm=qac[3,2], out5 = TRUE, am = qac[3,4])[,1])
q0004f <- data.frame(period="2000-2004", sex="female",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="female", cm=qac[4,2], out5 = TRUE, am = qac[4,4])[,1])

q8589m <- data.frame(period="1985-1989", sex="male",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="male", cm=qac[1,3], out5 = TRUE, am = qac[1,5])[,1])
q9094m <- data.frame(period="1990-1994", sex="male",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="male", cm=qac[2,3], out5 = TRUE, am = qac[2,5])[,1])
q9599m <- data.frame(period="1995-1999", sex="male",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="male", cm=qac[3,3], out5 = TRUE, am = qac[3,5])[,1])
q0004m <- data.frame(period="2000-2004", sex="male",age=c(0,1,seq(5,110,5)), 
                     qx=predictLT(sex="male", cm=qac[4,3], out5 = TRUE, am = qac[4,5])[,1])

ltsvdqx <- rbind(q8589f, q9094f, q9599f, q0004f, q8589m, q9094m, q9599m, q0004m) 
radix <- 1


qsvd5080un  <-  ddply(ltsvdqx, .(period,sex), summarise, lx=c(radix, cumprod(1 - qx)[-length(qx)])*100000) %>%
                  cbind(age=rep(c(0,1,seq(5,110,5)),8)) %>%
                  ddply(.(period,sex), summarise, q5080=1-lx[age==80]/lx[age==50])
  

# ## Creating the Wilmoth class object to estimate mortality rates
# Wf <- wilmoth(x= c(0,1, seq(5, 110, by = 5)), LT = HMD719[HMD719$sex == "female",])
# Wm <- wilmoth(x= c(0,1, seq(5, 110, by = 5)), LT = HMD719[HMD719$sex == "male",])
# 
# # length from 0, 1, 5 until age 85
# fitage <- seq(15,90,5) 
# l      <- length(c(0,1, seq(5,90,5)))
# 
# 
# lqf <- wilmothLT(Wf, q0_5 = qac[1,2], q15_45 = qac[1,4])$lt %>% 
#                  mutate(age=x, sex="f", period="1985-1989") %>%
#        rbind(wilmothLT(Wf, q0_5 = qac[2,2], q15_45 = qac[2,4])$lt %>% 
#              mutate(age=x, sex="f", period="1990-1994")) %>%
#        rbind(wilmothLT(Wf, q0_5 = qac[3,2], q15_45 = qac[3,4])$lt %>% 
#              mutate(age=x, sex="f", period="1995-1999")) %>%
#        rbind(wilmothLT(Wf, q0_5 = qac[4,2], q15_45 = qac[4,4])$lt %>% 
#              mutate(age=x, sex="f", period="2000-2004"))
# lqm <- wilmothLT(Wm, q0_5 = qac[1,3], q15_45 = qac[1,5])$lt %>% 
#                  mutate(age=x, sex="m", period="1985-1989") %>%
#        rbind(wilmothLT(Wm, q0_5 = qac[2,3], q15_45 = qac[2,5])$lt %>% 
#              mutate(age=x, sex="m", period="1990-1994")) %>%
#        rbind(wilmothLT(Wm, q0_5 = qac[3,3], q15_45 = qac[3,5])$lt %>% 
#              mutate(age=x, sex="m", period="1995-1999")) %>%
#        rbind(wilmothLT(Wm, q0_5 = qac[4,3], q15_45 = qac[4,5])$lt %>% 
#              mutate(age=x, sex="m", period="2000-2004"))
# 
# rbind(lqf, lqm) %>%
#   ddply(.(period, sex), summarise, qold=1-lx[age==80]/lx[age==50])

###############################################################################################
# COMPARISON OF AGE PATTERNS WITH HMD LT USING SIMILAR REMAINING LIFE EXPECTANCY BEFORE AGE 50 (e48)
library(HMDHFDplus)
# Defining username and password to load the HMD LT
us  <- "ouedraso2000@gmail.com"
pw  <- "SoumEdsd1617"

countries <- getHMDcountries() # returns vector of HMD country codes

### Function to import Life tables for all countries
LT <- do.call(rbind,  # (idiom to rbind a list of data.frames together)
              # using lapply() to stick everything in a list 
              lapply(countries, function(XYZ, 
                                         username = us, 
                                         password = pw){ 
                # print progress to console
                cat(XYZ,"\n")
                # male lifetables
                LTM      <- readHMDweb(XYZ, "mltper_1x1", 
                                       username = us, 
                                       password = pw)  
                # female lifetable
                LTF      <- readHMDweb(XYZ, "fltper_1x1", 
                                       username = us, 
                                       password = pw) 
                # add sex columns
                LTM$Sex  <- "m"
                LTF$Sex  <- "f"
                # add males and females together
                LT       <- rbind(LTM, LTF)
                # add country name
                LT$CNTRY <- XYZ
                LT                                          
                }, 
                username = us, password = pw
                )
              )

# Importing all HMD universe data (excluding years without data)
LTe50 <- na.omit(LT) 

# Computing mortality indices from HMD universe
hmdrqx <- ddply(na.omit(LTe50),.(CNTRY,Year,Sex), summarise, 
          q05=1-lx[Age==5]/lx[Age==0],
          q1560=1-lx[Age==60]/lx[Age==15],
          q5070=1-lx[Age==70]/lx[Age==50],
          q6070=1-lx[Age==70]/lx[Age==60],
          q7080=1-lx[Age==80]/lx[Age==70],
          q5080=1-lx[Age==80]/lx[Age==50]) %>%
          rename(c("Sex"="sex"))


# Data frame of different mortality indices (probabilities of death)
obsqx <- ddply(dft, .(period, sex, method), summarize, q1560 = 1- lx[age==60]/lx[age==15]) %>%
          mutate(cod=ifelse(sex=="f" & period=="1985-1996", 1,
                            ifelse(sex=="f" & period=="1996-2006", 3,
                                   ifelse(sex=="m" & period=="1985-1996",2, 4)))) %>%
          rbind(ddply(dft, .(period, sex, method), summarize, q1560 = 1- lx[age==60]/lx[age==15]) %>%
          mutate(cod=ifelse(sex=="f" & period=="1985-1996", 1,
                            ifelse(sex=="f" & period=="1996-2006", 3,
                                   ifelse(sex=="m" & period=="1985-1996",2, 4)))) %>%
          filter(method=="Adjusted for incompleteness") %>% 
          mutate(method=recode(method, "Adjusted for incompleteness"="MKH model"))) %>%
          left_join(par.input[, c(1,2)], by.x=c("cod")) %>%
          left_join(dft %>% 
                      mutate(cod=ifelse(sex=="f" & period=="1985-1996", 1,
                                        ifelse(sex=="f" & period=="1996-2006", 3,
                                               ifelse(sex=="m" & period=="1985-1996",2, 4)))) %>%
                      ddply( .(cod, method), summarize, 
                             #q1560 = 1- lx[age==60]/lx[age==50],
                             q5060 = 1- lx[age==60]/lx[age==50],
                             q6070 = 1- lx[age==70]/lx[age==60],
                             q7080 = 1- lx[age==80]/lx[age==70],
                             q5070 = 1- lx[age==70]/lx[age==50],
                             q5080 = 1- lx[age==80]/lx[age==50]), by.x=c("cod","method"))
  

# plotting relation between 5q0 and 20q50
hmd1q05 <- ggplot() +
            geom_point(data=hmdrqx, aes(x=q05, y=q5070, color="HMD"), size=2) + 
            geom_point(data=obsqx, aes(x=q05, y=q5070, color=method, shape=period), size=3) +
            scale_color_manual(values=c("SVD model"="darkred","BRASS model"="orange", 
                                       "Adjusted for incompleteness"="black",
                                       "MKH model"="yellow3", "HMD"="gray90")) +
            scale_shape_manual(values=c("1985-1996"=15, "1996-2006"=18)) +
            labs(x=expression(""~{}[{5}]*q[0]~""), 
                 y=expression(""~{}[{20}]*q[50]~"")) +
            facet_grid(cols=vars(sex), labeller = labeller(sex=c(f="Females",m="Males"))) +
            guides(color=guide_legend(ncol=3, byrow=TRUE, override.aes = list(size=3), title="Method"),
                   shape=guide_legend(ncol=1, byrow=F, override.aes = list(size=3),  title="Period")) +
            theme_bw() +  theme(legend.title = element_text(size=14),legend.position="bottom",
                                legend.spacing.y = unit(0.05,"cm"),
                                legend.spacing.x = unit(0.08,"cm"), 
                                panel.grid.minor = element_blank(), 
                                strip.text.x = element_text(size=9),
                                panel.grid.major.x = element_line(linetype=1, colour="grey95"),
                                axis.text.y=element_text(angle=0,vjust=0.25, hjust=1, size=9))

# plotting relation between 45q15 and 20q50
hmd1q1560 <- ggplot() +
              geom_point(data=hmdrqx, aes(x=q1560, y=q5070, color="HMD"), size=2) + 
              geom_point(data=obsqx, aes(x=q1560, y=q5070, color=method, shape=period), size=3) +
              scale_color_manual(values=c("SVD model"="darkred","BRASS model"="orange", 
                                          "Adjusted for incompleteness"="black",
                                          "MKH model"="yellow3", "HMD"="gray90")) +
              scale_shape_manual(values=c("1985-1996"=15, "1996-2006"=18)) +
              labs(x=expression(""~{}[{45}]*q[15]~""), 
                   y=expression(""~{}[{20}]*q[50]~"")) +
              facet_grid(cols=vars(sex), labeller = labeller(sex=c(f="Females",m="Males"))) +
              guides(color=guide_legend(ncol=3, byrow=TRUE, override.aes = list(size=3), title="Method"),
                     shape=guide_legend(ncol=1, byrow=F, override.aes = list(size=3),  title="Period")) +
              theme_bw() +  theme(legend.position="none",
                                  panel.grid.minor = element_blank(), 
                                  strip.text.x = element_text(size=9),
                                  panel.grid.major.x = element_line(linetype=1, colour="grey95"),
                                  axis.text.y=element_text(angle=0,vjust=0.25, hjust=1, size=9))

# plotting relation between 5q0 and 10q70
hmd2q05 <- ggplot() +
            geom_point(data=hmdrqx, aes(x=q05, y=q7080, color="HMD"), size=2) + 
            geom_point(data=obsqx, aes(x=q05, y=q7080, color=method, shape=period), size=3) +
            scale_color_manual(values=c("SVD model"="darkred","BRASS model"="orange", 
                                        "Adjusted for incompleteness"="black",
                                        "MKH model"="yellow3", "HMD"="gray90")) +
            scale_shape_manual(values=c("1985-1996"=15, "1996-2006"=18)) +
            labs(x=expression(""~{}[{5}]*q[0]~""), 
                 y=expression(""~{}[{10}]*q[70]~"")) +
            facet_grid(cols=vars(sex), labeller = labeller(sex=c(f="Females",m="Males"))) +
            guides(color=guide_legend(ncol=3, byrow=TRUE, override.aes = list(size=3), title="Method"),
                   shape=guide_legend(ncol=1, byrow=F, override.aes = list(size=3),  title="Period")) +
            theme_bw() +  theme(legend.title = element_text(size=14),legend.position="bottom",
                                legend.spacing.y = unit(0.05,"cm"),
                                legend.spacing.x = unit(0.08,"cm"), 
                                panel.grid.minor = element_blank(), 
                                strip.text.x = element_text(size=9),
                                panel.grid.major.x = element_line(linetype=1, colour="grey95"),
                                axis.text.y=element_text(angle=0,vjust=0.25, hjust=1, size=9))

# plotting relation between 45q15 and 10q70
hmd2q1560 <- ggplot() +
              geom_point(data=hmdrqx, aes(x=q1560, y=q7080, color="HMD"), size=2) + 
              geom_point(data=obsqx, aes(x=q1560, y=q7080, color=method, shape=period), size=3) +
              scale_color_manual(values=c("SVD model"="darkred","BRASS model"="orange", 
                                          "Adjusted for incompleteness"="black",
                                          "MKH model"="yellow3", "HMD"="gray90")) +
              scale_shape_manual(values=c("1985-1996"=15, "1996-2006"=18)) +
              labs(x=expression(""~{}[{45}]*q[15]~""), 
                   y=expression(""~{}[{10}]*q[70]~"")) +
              facet_grid(cols=vars(sex), labeller = labeller(sex=c(f="Females",m="Males"))) +
              guides(color=guide_legend(ncol=3, byrow=TRUE, override.aes = list(size=3), title="Method"),
                     shape=guide_legend(ncol=1, byrow=F, override.aes = list(size=3),  title="Period")) +
              theme_bw() +  theme(legend.position="none",
                                  panel.grid.minor = element_blank(), 
                                  strip.text.x = element_text(size=9),
                                  panel.grid.major.x = element_line(linetype=1, colour="grey95"),
                                  axis.text.y=element_text(angle=0,vjust=0.25, hjust=1, size=9))

# Saving the comparison plots with the estimates of HMD universe 
grid.newpage()
ggsave(filename="hmdplot.png",
       plot = ggarrange(hmd1q1560, hmd2q1560, hmd1q05, hmd2q05, ncol=2, nrow=2, common.legend = TRUE, legend="bottom"),
       width=8, height=6)
dev.off()






















